README
======

A Python package implementing the Voronoi Cell Finite Element Method (VCFEM)
for analysis of problems in geomechanics.

.. _Brandon Karchewski: brandon.karchewski@ucalgary.ca
.. _GitHub: https://github.com/karcheba1/vcfempy/

For information about the project, to view source code, and to report issues
visit the project repo page on GitHub_. For more information and to discuss
collaboration contact `Brandon Karchewski`_.
